Learn R Programming

tsriadditive (version 1.0.0)

summary.tsriadditive: Summarizing Additive Hazards Model with Two Stage Residual Inclusion Method Fits

Description

summary method for class "tsriadditive".

Usage

# S3 method for tsriadditive
summary(object, ...)

# S3 method for summary.tsriadditive print(x, ...)

Arguments

object

an object of class "tsriadditive", usually, a result of a call to tsriadditive.

...

further arguments passed to or from other methods.

x

an object of class "summary.tsriadditive", usually, a result of a call to summary.tsriadditive.

Value

print.summary.lm tries to be smart about formatting coefficients, an estimated variance covariance matrix of the coeffieients, Z-values and the corresponding P-values

Examples

Run this code
# NOT RUN {
survtime <- rexp(100)
cause <- rbinom(100, 1, 0.7)
treatment <- rbinom(100, 1, 0.5)
IV <- rnorm(100)
covariates <- rnorm(100)
fit <- tsriadditive(survtime, cause, treatment, IV, covariates)
summary(fit)
# }

Run the code above in your browser using DataLab